aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorOle Trøan <otroan@employees.org>2018-11-22 10:01:09 +0000
committerOle Trøan <otroan@employees.org>2018-11-22 10:01:09 +0000
commit5ba9159a157141554e53af9821c8da07a93da7ff (patch)
tree3d77a8677a5d7e5bad4df8062a634cbe40d98e32
parentc32023b9fd6970ed1cac1b3c7f36233b536d9968 (diff)
Revert "Fix instance method call in test/framework.py"
This reverts commit c32023b9fd6970ed1cac1b3c7f36233b536d9968. Change-Id: Ic934d223b10028093b0262e28515bde3ae1ccb71 Signed-off-by: Ole Troan <ot@cisco.com>
-rw-r--r--test/framework.py15
-rw-r--r--test/run_tests.py8
2 files changed, 15 insertions, 8 deletions
diff --git a/test/framework.py b/test/framework.py
index 019f366dabe..4c536e062b0 100644
--- a/test/framework.py
+++ b/test/framework.py
@@ -983,6 +983,14 @@ def get_testcase_doc_name(test):
return getdoc(test.__class__).splitlines()[0]
+def get_test_description(descriptions, test):
+ short_description = test.shortDescription()
+ if descriptions and short_description:
+ return short_description
+ else:
+ return str(test)
+
+
class TestCaseInfo(object):
def __init__(self, logger, tempdir, vpp_pid, vpp_bin_path):
self.logger = logger
@@ -1167,12 +1175,7 @@ class VppTestResult(unittest.TestResult):
:returns: test description
"""
- # TODO: if none print warning not raise exception
- short_description = test.shortDescription()
- if self.descriptions and short_description:
- return short_description
- else:
- return str(test)
+ return get_test_description(self.descriptions, test)
def startTest(self, test):
"""
diff --git a/test/run_tests.py b/test/run_tests.py
index 361990b8931..b2de2e702fb 100644
--- a/test/run_tests.py
+++ b/test/run_tests.py
@@ -15,7 +15,7 @@ from multiprocessing import Process, Pipe, cpu_count
from multiprocessing.queues import Queue
from multiprocessing.managers import BaseManager
from framework import VppTestRunner, running_extended_tests, VppTestCase, \
get_testcase_doc_name, PASS, FAIL, ERROR, SKIP, \
TEST_RUN
from debug import spawn_gdb
from log import get_parallel_logger, double_line_delim, RED, YELLOW, GREEN, \
@@ -88,7 +88,7 @@ class TestResult(dict):
def get_testcase_names(self, test_id):
if re.match(r'.+\..+\..+', test_id):
- test_name = test_id.getDescription()
+ test_name = self._get_test_description(test_id)
testcase_name = self._get_testcase_doc_name(test_id)
else:
# could be tearDownClass (test_ipsec_esp.TestIpsecEsp1)
@@ -108,6 +108,10 @@ class TestResult(dict):
return testcase_name, test_name
+ def _get_test_description(self, test_id):
+ return get_test_description(descriptions,
+ self.testcases_by_id[test_id])
+
def _get_testcase_doc_name(self, test_id):
return get_testcase_doc_name(self.testcases_by_id[test_id])
@@ -15,7 +15,7 @@ from multiprocessing import Process, Pipe, cpu_count
from multiprocessing.managers import BaseManager
from framework import VppTestRunner, running_extended_tests, VppTestCase, \
- get_testcase_doc_name, PASS, FAIL, ERROR, SKIP, \
+ get_testcase_doc_name, get_test_description, PASS, FAIL, ERROR, SKIP, \
TEST_RUN
from debug import spawn_gdb